import React from "react"

import PropTypes from "prop-types"

import TextField from "@mui/material/TextField"

import Box from "@mui/material/Box"
import { styled } from "@mui/material/styles"

import ContactButton from "./ContactButton"

const CustomTextField = styled(TextField)(({ theme, borderColor, textColor }) => ({
  "& label.Mui-focused": {
    color: textColor,
  },
  "& .MuiInput-underline:after": {
    borderBottomColor: borderColor,
  },
  "& .MuiOutlinedInput-root": {
    "& fieldset": {
      borderColor: borderColor,
    },
    "&:hover fieldset": {
      borderColor: borderColor,
    },
    "&.Mui-focused fieldset": {
      borderColor: borderColor,
    },
  },
}))

function FormFooter({borderColor, textColor}) {
  const handleSubmit = (event) => {
    event.preventDefault()
    const data = new FormData(event.currentTarget)
    // eslint-disable-next-line no-console
    console.log({
      email: data.get("nombre"),
      password: data.get("password"),
    })
  }

  return (
    <Box component="form" onSubmit={handleSubmit} noValidate>
      <CustomTextField 
        borderColor={borderColor}
        textColor={textColor}
        margin="normal"
        required
        fullWidth
        id="name"
        label="Nombre"
        name="name"
        autoComplete="name"
      />
      <CustomTextField
        borderColor={borderColor}
        textColor={textColor}
        margin="normal"
        required
        fullWidth
        name="email"
        label="Email"
        type="email"
        id="email"
        autoComplete="email"
      />
      <CustomTextField
        borderColor={borderColor}
        textColor={textColor}
        margin="normal"
        required
        fullWidth
        name="phone"
        label="Teléfono"
        type="number"
        id="phone"
        autoComplete="phone"
      />
      <ContactButton width="100%">
        Contáctanos
      </ContactButton>
    </Box>
  )
}

FormFooter.propTypes = {
  borderColor: PropTypes.string.isRequired,
  textColor: PropTypes.string.isRequired,
}

export default FormFooter
